from .data_loader import load_data
from .data_cleaner import clean_data
from .data_validator import validate_data
from .data_visualizer import visualize_data
from .report_generator import generate_report

__all__ = [
    'load_data',
    'clean_data',
    'validate_data',
    'visualize_data',
    'generate_report',
    'analyze_data'
]


def analyze_data(file_path):
    """Main function to execute complete analysis workflow"""
    from .data_loader import load_data
    from .data_cleaner import clean_data
    from .data_validator import validate_data
    from .data_visualizer import visualize_data
    from .report_generator import generate_report

    print("🚀 Starting Data Analysis Pipeline\n")

    # Load data
    df = load_data(file_path)
    if df is None:
        return

    # Data cleaning
    df = clean_data(df)

    # Data validation
    validate_data(df)

    # Data visualization
    visualize_data(df)

    # Generate final report
    generate_report(df)

    print("\n🎉 Analysis Complete! Check generated files for results.")